@@ -248,7 +248,8 @@ gweather_gconf_get_location(GWeatherGConf *ctx)
 	    coordinates = g_strdup ("40-32N 080-13W");
     }
     
-    location = weather_location_new (name, code, zone, radar, coordinates);
+    location = weather_location_new (name, code, zone, radar, coordinates,
+				     NULL, NULL);
     
     g_free (name);
     g_free (code);
